/*
Licensed to the Apache Software Foundation (ASF) under one or more
contributor license agreements.  See the NOTICE file distributed with
this work for additional information regarding copyright ownership.
The ASF licenses this file to You under the Apache License, Version 2.0
(the "License"); you may not use this file except in compliance with
the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package models

import (
	"github.com/apache/incubator-devlake/core/models/common"
	"github.com/apache/incubator-devlake/core/plugin"
)

var _ plugin.ToolLayerScope = (*TrelloBoard)(nil)

type TrelloBoard struct {
	common.Scope `mapstructure:",squash"`
	ConnectionId uint64 `json:"connectionId" mapstructure:"connectionId" gorm:"primaryKey"`
	BoardId      string `json:"boardId" mapstructure:"boardId" gorm:"type:varchar(255)"`
	Name         string `json:"name" mapstructure:"name" gorm:"type:varchar(255)"`
}

func (b TrelloBoard) ScopeId() string {
	return b.BoardId
}

func (b TrelloBoard) ScopeName() string {
	return b.Name
}

func (b TrelloBoard) ScopeFullName() string {
	return b.Name
}

func (b TrelloBoard) ScopeParams() interface{} {
	return &TrelloApiParams{
		ConnectionId: b.ConnectionId,
		BoardId:      b.BoardId,
	}
}

func (TrelloBoard) TableName() string {
	return "_tool_trello_boards"
}

type TrelloApiParams struct {
	ConnectionId uint64
	BoardId      string
}
